@@ -21,6 +21,7 @@
 #include <QKeyEvent>
 #include <QMenu>
 #include <QSortFilterProxyModel>
+#include <QProxyStyle>
 
 #include <libaudcore/audstrings.h>
 #include <libaudcore/drct.h>
@@ -59,6 +60,8 @@ PlaylistWidget::PlaylistWidget(QWidget * parent, Playlist playlist)
     setDragDropMode(DragDrop);
     setMouseTracking(true);
 
+    connect(this, &QTreeView::doubleClicked, this, &PlaylistWidget::doubleClick);
+
     updateSettings();
     header->updateColumns();
 
@@ -115,7 +118,7 @@ QModelIndex PlaylistWidget::visibleIndexNear(int row)
     return index;
 }
 
-void PlaylistWidget::activate(const QModelIndex & index)
+void PlaylistWidget::doubleClick(const QModelIndex & index)
 {
     if (index.isValid())
     {
